#include <math.h>
#include <iostream>
#include <vector>
#include <string>
#include "svg.hpp"
using namespace std;

void
svg_begin(double width, double height)
{
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
svg_end()
{
    cout << "</svg>\n";
}

void
svg_text(double left, double baseline, string text)
{
    cout << "<text x='" << left << "' y='" << baseline << "'>" << text << "</text>";
}

void
svg_rect(double x, double y, double width, double height, string stroke = "black", string fill = "black")
{
    cout << "<rect x='"<<x<<"' y='"<<y<<"' width='"<<width<<"' height='"<<height<<"' stroke='"<<stroke<<"' fill='"<<fill<<"'";
}


void
show_histogram_svg(const vector<size_t>& bins)
{
    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 300;
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BOARD_COLOR = "black";
    const auto FILL_COLOR = "red";
    const auto MAX_WIDTH = IMAGE_WIDTH-TEXT_WIDTH; 


    svg_begin(IMAGE_WIDTH,IMAGE_HEIGHT);

    double top = 0;
    double max_count = bins[0];
    for (size_t i = 0; i < bins.size(); i++)
    {
        if (max_count<bins[i])
        {
            max_count=bins[i];
        }
    }

    for (size_t i=0; i < bins.size(); i++)
        {
            double bin_width = (MAX_WIDTH)*(bins[i]/max_count);
            double opacity = (bins[i]/max_count);
            string fill_opacity = to_string(opacity);
            svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bins[i]));
            svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, BOARD_COLOR, FILL_COLOR);
            cout << " fill-opacity ='" << fill_opacity << "'" << " /> ";
            top += BIN_HEIGHT;
        }

        svg_end();
    }
